@@ -20,7 +20,7 @@ input Where{scalar} {'{'}
     eq: {scalar}
     neq: {scalar}
 {'}'}
-""" for scalar in map(str, searchables)])
+""" for scalar in map(str, sorted(searchables))])
 }}
 
 
@@ -44,7 +44,7 @@ extend type Query {
         where: ${{type_name}}Where,
     ): ${{type_name}}
 
-    ${{query_name}}s(
+    ${{query_name}}Nodes(
         where: ${{type_name}}Where, 
         cursorField: ${{type_name}}Fields, 
         first: Int, 
